@@ -1,32 +1,28 @@
-from copy import deepcopy
-
 import json
 import logging
-import psycopg2
 import re
 from abc import ABC, abstractmethod
-from psycopg2.sql import SQL, Identifier
-from typing import Optional, Mapping, Dict, List, Any, cast, TYPE_CHECKING, Tuple
+from copy import deepcopy
+from typing import TYPE_CHECKING, Any, Dict, List, Mapping, Optional, Tuple, cast
 
+import psycopg2
+from psycopg2.sql import SQL, Identifier
 from splitgraph.core.types import (
-    TableSchema,
-    TableColumn,
-    dict_to_table_schema_params,
-    TableParams,
-    TableInfo,
-    PreviewResult,
-    MountError,
-    IntrospectionResult,
     Credentials,
+    IntrospectionResult,
+    MountError,
+    PreviewResult,
+    TableColumn,
+    TableInfo,
+    TableParams,
+    TableSchema,
+    dict_to_table_schema_params,
 )
-from splitgraph.exceptions import get_exception_name, DataSourceError
-from splitgraph.hooks.data_source.base import (
-    MountableDataSource,
-    LoadableDataSource,
-)
+from splitgraph.exceptions import DataSourceError, get_exception_name
+from splitgraph.hooks.data_source.base import LoadableDataSource, MountableDataSource
 
 if TYPE_CHECKING:
-    from splitgraph.engine.postgres.engine import PostgresEngine
+    from splitgraph.engine.postgres.engine import PsycopgEngine
 
 
 class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC):
@@ -167,8 +163,8 @@ class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC)
         # to mount the actual table. By default, just call out into mount()
 
         # Local import here since this data source gets imported by the commandline entry point
-        from splitgraph.core.common import get_temporary_table_id
         import jsonschema
+        from splitgraph.core.common import get_temporary_table_id
 
         tmp_schema = get_temporary_table_id()
         try:
@@ -291,7 +287,10 @@ class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC)
                     self.engine.copy_table(tmp_schema, t, schema, t)
                     self.engine.commit()
                 except psycopg2.DatabaseError as e:
-                    logging.warning("Error ingesting table %s", t, exc_info=e)
+                    logging.exception("Error ingesting table %s", t, exc_info=e)
+                    raise DataSourceError(
+                        "Error ingesting table %s: %s: %s" % (t, get_exception_name(e), e)
+                    )
         finally:
             self.engine.rollback()
             self.engine.delete_schema(tmp_schema)
@@ -299,11 +298,12 @@ class ForeignDataWrapperDataSource(MountableDataSource, LoadableDataSource, ABC)
 
 
 def init_fdw(
-    engine: "PostgresEngine",
+    engine: "PsycopgEngine",
     server_id: str,
     wrapper: str,
     server_options: Optional[Mapping[str, Optional[str]]] = None,
     user_options: Optional[Mapping[str, str]] = None,
+    role: Optional[str] = None,
     overwrite: bool = True,
 ) -> None:
     """
@@ -314,9 +314,10 @@ def init_fdw(
     :param wrapper: Name of the foreign data wrapper (must be installed as an extension on the engine)
     :param server_options: Dictionary of FDW options
     :param user_options: Dictionary of user options
+    :param role: The name of the role for which the user mapping is created; defaults to public.
     :param overwrite: If the server already exists, delete and recreate it.
     """
-    from psycopg2.sql import Identifier, SQL
+    from psycopg2.sql import SQL, Identifier
 
     if overwrite:
         engine.run_sql(SQL("DROP SERVER IF EXISTS {} CASCADE").format(Identifier(server_id)))
@@ -333,8 +334,8 @@ def init_fdw(
         engine.run_sql(create_server)
 
     if user_options:
-        create_mapping = SQL("CREATE USER MAPPING IF NOT EXISTS FOR PUBLIC SERVER {}").format(
-            Identifier(server_id)
+        create_mapping = SQL("CREATE USER MAPPING IF NOT EXISTS FOR {} SERVER {}").format(
+            SQL("PUBLIC") if role is None else Identifier(role), Identifier(server_id)
         )
         user_keys, user_vals = zip(*user_options.items())
         create_mapping += _format_options(user_keys)
@@ -342,7 +343,7 @@ def init_fdw(
 
 
 def _format_options(option_names):
-    from psycopg2.sql import Identifier, SQL
+    from psycopg2.sql import SQL, Identifier
 
     return (
         SQL(" OPTIONS (")
@@ -352,14 +353,14 @@ def _format_options(option_names):
 
 
 def import_foreign_schema(
-    engine: "PostgresEngine",
+    engine: "PsycopgEngine",
     mountpoint: str,
     remote_schema: str,
     server_id: str,
     tables: List[str],
     options: Optional[Dict[str, str]] = None,
 ) -> List[MountError]:
-    from psycopg2.sql import Identifier, SQL
+    from psycopg2.sql import SQL, Identifier
 
     # Construct a query: import schema limit to (%s, %s, ...) from server mountpoint_server into mountpoint
     query = SQL("IMPORT FOREIGN SCHEMA {} ").format(Identifier(remote_schema))
@@ -529,8 +530,8 @@ Mounts one or more collections on a remote Mongo database as a set of foreign ta
 {
     "table_name": {
         "schema": {"col1": "type1"...},
-        "options": {"database": <dbname>, "collection": <collection>} 
-    } 
+        "options": {"database": <dbname>, "collection": <collection>}
+    }
 }
 ```
 """
