@@ -1,17 +1,18 @@
 import logging
 import traceback
 from collections import Callable
-from datetime import datetime as dt
 from functools import wraps
-from typing import Optional, Dict, Any
+from typing import Any, Dict, Optional
 
 from psycopg2.sql import SQL, Identifier
-
 from splitgraph.core.repository import Repository
-from splitgraph.core.types import TableSchema, Changeset
+from splitgraph.core.types import Changeset, TableSchema
 from splitgraph.engine import validate_type
-from splitgraph.engine.postgres.engine import get_change_key, PostgresEngine
-from splitgraph.hooks.data_source.base import INGESTION_STATE_TABLE, INGESTION_STATE_SCHEMA
+from splitgraph.engine.postgres.engine import PostgresEngine, get_change_key
+from splitgraph.hooks.data_source.base import (
+    INGESTION_STATE_SCHEMA,
+    INGESTION_STATE_TABLE,
+)
 
 SingerConfig = Dict[str, Any]
 SingerCatalog = Dict[str, Any]
@@ -161,12 +162,3 @@ def store_ingestion_state(
             repository,
             [(image_hash, INGESTION_STATE_TABLE, INGESTION_STATE_SCHEMA, [object_id])],
         )
-
-
-def add_timestamp_tags(repository: Repository, image_hash: str):
-    ingestion_time = dt.utcnow()
-    short_tag = ingestion_time.strftime("%Y%m%d")
-    long_tag = short_tag + "-" + ingestion_time.strftime("%H%M%S")
-    new_image = repository.images.by_hash(image_hash)
-    new_image.tag(short_tag)
-    new_image.tag(long_tag)
